Index: trunk/sources/HeuristicLab.Algorithms.SGA.Views/3.3/Properties/AssemblyInfo.frame
===================================================================
--- trunk/sources/HeuristicLab.Algorithms.SGA.Views/3.3/Properties/AssemblyInfo.frame	(revision 3025)
+++ trunk/sources/HeuristicLab.Algorithms.SGA.Views/3.3/Properties/AssemblyInfo.frame	(revision 3026)
@@ -27,5 +27,5 @@
 // associated with an assembly.
 [assembly: AssemblyTitle("HeuristicLab.Algorithms.SGA.Views")]
-[assembly: AssemblyDescription("Views of the HeuristicLab Standard Genetic Algorithm (SGA)")]
+[assembly: AssemblyDescription("Views of the HeuristicLab standard genetic algorithm (SGA)")]
 [assembly: AssemblyConfiguration("")]
 [assembly: AssemblyCompany("")]
Index: trunk/sources/HeuristicLab.Algorithms.SGA/3.3/Properties/AssemblyInfo.frame
===================================================================
--- trunk/sources/HeuristicLab.Algorithms.SGA/3.3/Properties/AssemblyInfo.frame	(revision 3025)
+++ trunk/sources/HeuristicLab.Algorithms.SGA/3.3/Properties/AssemblyInfo.frame	(revision 3026)
@@ -27,5 +27,5 @@
 // associated with an assembly.
 [assembly: AssemblyTitle("HeuristicLab.Algorithms.SGA")]
-[assembly: AssemblyDescription("HeuristicLab Standard Genetic Algorithm (SGA)")]
+[assembly: AssemblyDescription("HeuristicLab standard genetic algorithm (SGA)")]
 [assembly: AssemblyConfiguration("")]
 [assembly: AssemblyCompany("")]
Index: trunk/sources/HeuristicLab.Algorithms.SGA/3.3/Tests/Properties/AssemblyInfo.cs
===================================================================
--- trunk/sources/HeuristicLab.Algorithms.SGA/3.3/Tests/Properties/AssemblyInfo.cs	(revision 3025)
+++ trunk/sources/HeuristicLab.Algorithms.SGA/3.3/Tests/Properties/AssemblyInfo.cs	(revision 3026)
@@ -7,5 +7,5 @@
 // associated with an assembly.
 [assembly: AssemblyTitle("HeuristicLab.Algorithms.SGA-3.3.Tests")]
-[assembly: AssemblyDescription("Unit tests for the HeuristicLab Standard Genetic Algorithm (SGA)")]
+[assembly: AssemblyDescription("Unit tests for the HeuristicLab standard genetic algorithm (SGA)")]
 [assembly: AssemblyConfiguration("")]
 [assembly: AssemblyCompany("")]
Index: trunk/sources/HeuristicLab.Algorithms.TS/3.3/Properties/AssemblyInfo.frame
===================================================================
--- trunk/sources/HeuristicLab.Algorithms.TS/3.3/Properties/AssemblyInfo.frame	(revision 3025)
+++ trunk/sources/HeuristicLab.Algorithms.TS/3.3/Properties/AssemblyInfo.frame	(revision 3026)
@@ -27,5 +27,5 @@
 // associated with an assembly.
 [assembly: AssemblyTitle("HeuristicLab.Algorithms.TS")]
-[assembly: AssemblyDescription("HeuristicLab Tabu Search (TS)")]
+[assembly: AssemblyDescription("HeuristicLab tabu search (TS)")]
 [assembly: AssemblyConfiguration("")]
 [assembly: AssemblyCompany("")]
Index: trunk/sources/HeuristicLab.Algorithms.TS/3.3/TSOperator.cs
===================================================================
--- trunk/sources/HeuristicLab.Algorithms.TS/3.3/TSOperator.cs	(revision 3025)
+++ trunk/sources/HeuristicLab.Algorithms.TS/3.3/TSOperator.cs	(revision 3026)
@@ -30,7 +30,7 @@
 namespace HeuristicLab.Algorithms.TS {
   /// <summary>
-  /// An operator which represents a Tabu Search.
+  /// An operator which represents a tabu search.
   /// </summary>
-  [Item("TSOperator", "An operator which represents a Tabu Search.")]
+  [Item("TSOperator", "An operator which represents a tabu search.")]
   [StorableClass]
   public class TSOperator : AlgorithmOperator {
Index: trunk/sources/HeuristicLab.Encodings.Permutation/3.3/Crossovers/EdgeRecombinationCrossover.cs
===================================================================
--- trunk/sources/HeuristicLab.Encodings.Permutation/3.3/Crossovers/EdgeRecombinationCrossover.cs	(revision 3025)
+++ trunk/sources/HeuristicLab.Encodings.Permutation/3.3/Crossovers/EdgeRecombinationCrossover.cs	(revision 3026)
@@ -31,8 +31,8 @@
   /// </summary>
   /// <remarks>
-  /// It is implemented as described in Whitley et.al. 1991, The Traveling Salesman and Sequence Scheduling, in Davis, L. (Ed.), Handbook ov Genetic Algorithms, New York, pp. 350-372.<br />
+  /// It is implemented as described in Whitley et.al. 1991, The Traveling Salesman and Sequence Scheduling, in Davis, L. (Ed.), Handbook of Genetic Algorithms, New York, pp. 350-372.<br />
   /// The operator first determines all cycles in the permutation and then composes the offspring by alternating between the cycles of the two parents.
   /// </remarks>
-  [Item("EdgeRecombinationCrossover", "An operator which performs the edge recombination crossover on two permutations. It is implemented as described in Whitley et.al. 1991, The Traveling Salesman and Sequence Scheduling, in Davis, L. (Ed.), Handbook ov Genetic Algorithms, New York, pp. 350-372.")]
+  [Item("EdgeRecombinationCrossover", "An operator which performs the edge recombination crossover on two permutations. It is implemented as described in Whitley et.al. 1991, The Traveling Salesman and Sequence Scheduling, in Davis, L. (Ed.), Handbook of Genetic Algorithms, New York, pp. 350-372.")]
   [StorableClass]
   [Creatable("Test")]
Index: trunk/sources/HeuristicLab.Encodings.RealVector/3.3/Manipulators/BreederGeneticAlgorithmManipulator.cs
===================================================================
--- trunk/sources/HeuristicLab.Encodings.RealVector/3.3/Manipulators/BreederGeneticAlgorithmManipulator.cs	(revision 3025)
+++ trunk/sources/HeuristicLab.Encodings.RealVector/3.3/Manipulators/BreederGeneticAlgorithmManipulator.cs	(revision 3026)
@@ -59,5 +59,5 @@
 
     /// <summary>
-    /// Performs a Breeder Genetic Algorithm Manipulation on the given <paramref name="vector"/>.
+    /// Performs a breeder genetic algorithm manipulation on the given <paramref name="vector"/>.
     /// </summary>
     /// <param name="random">A random number generator.</param>

Index: trunk/sources/HeuristicLab.Algorithms.SGA/3.3/SGAMainLoop.cs
===================================================================
--- trunk/sources/HeuristicLab.Algorithms.SGA/3.3/SGAMainLoop.cs	(revision 3025)
+++ trunk/sources/HeuristicLab.Algorithms.SGA/3.3/SGAMainLoop.cs	(revision 3026)
@@ -31,7 +31,7 @@
 namespace HeuristicLab.Algorithms.SGA {
   /// <summary>
   /// An operator which represents the main loop of a Standard Genetic Algorithm.
   /// </summary>
-  [Item("SGAMainLoop", "An operator which represents the main loop of a Standard Genetic Algorithm.")]
+  [Item("SGAMainLoop", "An operator which represents the main loop of a standard genetic algorithm (SGA).")]
   [Creatable("Test")]
   [StorableClass]
@@ -31,7 +31,7 @@
 namespace HeuristicLab.Algorithms.SGA {
   /// <summary>
-  /// An operator which represents the main loop of a Standard Genetic Algorithm.
+  /// An operator which represents the main loop of a standard genetic algorithm (SGA).
   /// </summary>